UrlBasedHistory class abstract

Base class for web History implementations backed by window.history.

This class wires up the browser popstate event and implements:

Inheritance
Implementers

Constructors

UrlBasedHistory({String? base, Window? window})

Properties

action ↔ HistoryAction
The last navigation action performed by this history.
getter/setter pairoverride-getter
base → String
The base path applied when creating hrefs.
final
hashCode → int
The hash code for this object.
no setterinherited
index ↔ int?
The current index in the history stack, if available.
getter/setter pairoverride-getter
listeners → List<HistoryListener>
final
location → HistoryLocation
The current location.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → HistoryState?
no setter
window ↔ Window
latefinal

Methods

back() → void
Equivalent to calling go with -1.
inherited
createHref(Uri uri) → String
Formats a Uri as an href for this history implementation.
inherited
dispose() → void
Releases resources held by the history (e.g. DOM event listeners).
override
forward() → void
Equivalent to calling go with +1.
inherited
go(int delta, {bool triggerListeners = true}) → void
Moves within the history stack by delta entries.
override
listen(HistoryListener listener) → void Function()
Registers a listener that is called when a pop navigation completes.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
push(Uri uri, {Object? state}) → void
Pushes a new history entry.
override
replace(Uri uri, {Object? state}) → void
Replaces the current history entry.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited